(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const CHAR_TYPE_MAP = {
        '+': 'Added',
        '-': 'Deleted',
        ' ': 'Unchanged',
    };
    function parseChanges(ctx, rangeBefore, rangeAfter) {
        const changes = [];
        let lineBefore = rangeBefore.start;
        let lineAfter = rangeAfter.start;
        while (!ctx.isEof()) {
            const line = ctx.getCurLine();
            const type = getLineType(line);
            if (!type) {
                break;
            }
            ctx.nextLine();
            let change;
            const content = line.slice(1);
            switch (type) {
                case 'Added': {
                    change = {
                        type: 'Added',
                        lineAfter: lineAfter++,
                        content,
                    };
                    break;
                }
                case 'Deleted': {
                    change = {
                        type: 'Deleted',
                        lineBefore: lineBefore++,
                        content,
                    };
                    break;
                }
                case 'Unchanged': {
                    change = {
                        type: 'Unchanged',
                        lineBefore: lineBefore++,
                        lineAfter: lineAfter++,
                        content,
                    };
                    break;
                }
            }
            changes.push(change);
        }
        return changes;
    }
    exports.default = parseChanges;
    function getLineType(line) {
        return CHAR_TYPE_MAP[line[0]] || null;
    }
});
