/**
 * Checks whether a line is a comparison input line or not.
 * @param {string} line The line to check.
 * @returns {boolean} Returns `true` if the given line is a comparison line, otherwise `false`.
 * @example
 * // comparison input line.
 * "diff --git a/file.txt b/file.txt"
 */
export declare function isComparisonInputLine(line: string): boolean;
/**
 * Checks whether a line is a meta data line or not.
 * @param line The line to check.
 * @returns {boolean} Return `true` if the given line is a meta data line, otherwise `false`.
 * @example
 * // meta data line.
 * "index 6b0c6cf..b37e70a 100644"
 */
export declare function isMetaDataLine(line: string): boolean;
export declare function isAddMarkerLine(line: string): boolean;
export declare function isDeleteMarkerLine(line: string): boolean;
/**
 * Checks whether the line is a chunk header or not
 * @param line The line to check.
 * @returns return `true` if the given line is a chunk header, otherwise `false`.
 * @example
 * // start line of diff chunks
 * "@@ -1 +1 @@ describe('utils', () => {..."
 * "@@ -23,15 +23,15 @@ describe('utils', () => { ..."
 */
export declare function isChunkHeader(line: string): boolean;
/**
 * Checks whether the line is an addition line.
 * @param {string} line The line to check.
 * @returns {boolean} Return `true` if the given line is an addition line, otherwise `false`.
 */
export declare function isAdditionLine(line: string): boolean;
/**
 * Checks whether the line is an deletion line.
 * @param {string} line The line to check.
 * @returns {boolean} Return `true` if the given line is an deletion line, otherwise `false`.
 */
export declare function isDeletionLine(line: string): boolean;
export declare function isUnchangedLine(line: string): boolean;
